@@ -21,19 +21,19 @@ use feature 'say';
 no strict;
 no warnings;
 
-use Sim::OPT; 
-use Sim::OPT::Morph; 
-use Sim::OPT::Sim; 
-use Sim::OPT::Report; 
-use Sim::OPT::Descend; 
-use Sim::OPT::Takechance; 
+use Sim::OPT;
+use Sim::OPT::Morph;
+use Sim::OPT::Sim;
+use Sim::OPT::Report;
+use Sim::OPT::Descend;
+use Sim::OPT::Takechance;
 use Sim::OPT::Parcoord3d;
 # NOTE THAT TO USE THE PROGRAM AS A SCRIPT, THE ABOVE "use Sim::OPT..." lines should be deleted.
 
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
-$VERSION = '0.121';
+$VERSION = '0.125';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -44,7 +44,7 @@ $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, m
 
 $tee = new IO::Tee(\*STDOUT, ">>$report"); # GLOBAL ZZZ
 my $maxloops= 1000;
-my $sourcefile = "./sourcefile.csv";
+my $sourcefile = "./prepfile.csv";
 my $newfile = $sourcefile . "_meta.csv";
 my $report = $newfile . "_report.txt";
 my @mode = ( "wei" ); # #"wei" is weighted gradient linear interpolation of the nearest neighbours.
@@ -805,7 +805,7 @@ sub wei
       { #say $tee "SO IN SECOND ARR CHECK" ; say $tee "\nTRYING \$el->[1]: " . dump( $el->[1] );
 
         my @neighbours;
-        if ( $el->[2] ne "" )
+        #if ( $el->[2] ne "" )
         {
           if ( scalar( @{ $nears{$el->[0]}{neighbours} } ) == 0 )
           {
